package com.yiqi.app.service;

import java.util.List;
import com.baomidou.mybatisplus.extension.service.IService;
import com.yiqi.app.domain.AppCouponTypeThirdParty;

/**
 * APP第三方管理Service接口
 *
 * @author ruoyi
 * @date 2023-11-13
 */
public interface IAppCouponTypeThirdPartyService extends IService<AppCouponTypeThirdParty> {

    //<editor-folder desc="基础韩素">
    /**
     * 查询APP第三方管理
     *
     * @param id APP第三方管理主键
     * @return APP第三方管理
     */
    public AppCouponTypeThirdParty selectAppCouponTypeThirdPartyById(Long id);

    /**
     * 查询APP第三方管理列表
     *
     * @param appCouponTypeThirdParty APP第三方管理
     * @return APP第三方管理集合
     */
    public List<AppCouponTypeThirdParty> selectAppCouponTypeThirdPartyList(AppCouponTypeThirdParty appCouponTypeThirdParty);

    /**
     * 新增APP第三方管理
     *
     * @param appCouponTypeThirdParty APP第三方管理
     * @return 结果
     */
    public int insertAppCouponTypeThirdParty(AppCouponTypeThirdParty appCouponTypeThirdParty);

    /**
     * 修改APP第三方管理
     *
     * @param appCouponTypeThirdParty APP第三方管理
     * @return 结果
     */
    public int updateAppCouponTypeThirdParty(AppCouponTypeThirdParty appCouponTypeThirdParty);

    /**
     * 批量删除APP第三方管理
     *
     * @param ids 需要删除的APP第三方管理主键集合
     * @return 结果
     */
    public int deleteAppCouponTypeThirdPartyByIds(Long[] ids);

    /**
     * 删除APP第三方管理信息
     *
     * @param id APP第三方管理主键
     * @return 结果
     */
    public int deleteAppCouponTypeThirdPartyById(Long id);


    /**
     * 修改APP第三方管理状态
     *
     * @param appCouponTypeThirdParty APP第三方管理
     * @return 结果
     */
    public int updateAppCouponTypeThirdPartyStatus(AppCouponTypeThirdParty appCouponTypeThirdParty);
    //</editor-folder>
}
