package com.yiqi.admin.controller.app;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import com.yiqi.common.constant.UrlConstants;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.yiqi.common.annotation.Log;
import com.yiqi.common.core.controller.BaseController;
import com.yiqi.common.core.domain.AjaxResult;
import com.yiqi.common.enums.BusinessType;
import com.yiqi.app.domain.AppCouponTypeThirdParty;
import com.yiqi.app.service.IAppCouponTypeThirdPartyService;
import com.yiqi.common.utils.poi.ExcelUtil;
import com.yiqi.common.core.page.TableDataInfo;

/**
 * APP第三方管理Controller
 *
 * @author ruoyi
 * @date 2023-11-13
 */
@Api(tags = "管理后台 - APP第三方管理")
@RestController
@RequestMapping(UrlConstants.managerApi + "/coupon/thirdParty")
public class AppCouponTypeThirdPartyController extends BaseController {
    @Autowired
    private IAppCouponTypeThirdPartyService appCouponTypeThirdPartyService;

    /**
     * 查询APP第三方管理列表
     */
    @PreAuthorize("@ss.hasPermi('coupon:thirdParty:list')")
    @GetMapping("/list")
    @ApiOperation(value = "查询APP第三方管理列表")
    public TableDataInfo list(AppCouponTypeThirdParty appCouponTypeThirdParty) {
        startPage();
        List<AppCouponTypeThirdParty> list = appCouponTypeThirdPartyService.selectAppCouponTypeThirdPartyList(appCouponTypeThirdParty);
        return getDataTable(list);
    }

    /**
     * 导出APP第三方管理列表
     */
    @PreAuthorize("@ss.hasPermi('coupon:thirdParty:export')")
    @Log(title = "APP第三方管理", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    @ApiOperation(value = "导出APP第三方管理列表")
    public void export(HttpServletResponse response, AppCouponTypeThirdParty appCouponTypeThirdParty) {
        List<AppCouponTypeThirdParty> list = appCouponTypeThirdPartyService.selectAppCouponTypeThirdPartyList(appCouponTypeThirdParty);
        ExcelUtil<AppCouponTypeThirdParty> util = new ExcelUtil<AppCouponTypeThirdParty>(AppCouponTypeThirdParty. class);
        util.exportExcel(response, list, "APP第三方管理数据");
    }

    /**
     * 获取APP第三方管理详细信息
     */
    @PreAuthorize("@ss.hasPermi('coupon:thirdParty:query')")
    @GetMapping(value = "/{id}")
    @ApiOperation(value = "获取APP第三方管理详细信息")
    public AjaxResult getInfo(@PathVariable("id") Long id) {
        return success(appCouponTypeThirdPartyService.selectAppCouponTypeThirdPartyById(id));
    }

    /**
     * 新增APP第三方管理
     */
    @PreAuthorize("@ss.hasPermi('coupon:thirdParty:add')")
    @Log(title = "APP第三方管理", businessType = BusinessType.INSERT)
    @PostMapping
    @ApiOperation(value = "新增APP第三方管理")
    public AjaxResult add(@RequestBody AppCouponTypeThirdParty appCouponTypeThirdParty) {
        appCouponTypeThirdParty.setCreateById(getUserId());
        appCouponTypeThirdParty.setCreateBy(getUsername());
        return toAjax(appCouponTypeThirdPartyService.insertAppCouponTypeThirdParty(appCouponTypeThirdParty));
    }

    /**
     * 修改APP第三方管理
     */
    @PreAuthorize("@ss.hasPermi('coupon:thirdParty:edit')")
    @Log(title = "APP第三方管理", businessType = BusinessType.UPDATE)
    @PutMapping
    @ApiOperation(value = "修改APP第三方管理")
    public AjaxResult edit(@RequestBody AppCouponTypeThirdParty appCouponTypeThirdParty) {
        appCouponTypeThirdParty.setUpdateById(getUserId());
        appCouponTypeThirdParty.setUpdateBy(getUsername());
        return toAjax(appCouponTypeThirdPartyService.updateAppCouponTypeThirdParty(appCouponTypeThirdParty));
    }

    /**
     * 删除APP第三方管理
     */
    @PreAuthorize("@ss.hasPermi('coupon:thirdParty:remove')")
    @Log(title = "APP第三方管理", businessType = BusinessType.DELETE)
    @DeleteMapping("/{ids}")
    @ApiOperation(value = "删除APP第三方管理")
    public AjaxResult remove(@PathVariable Long[] ids) {
        return toAjax(appCouponTypeThirdPartyService.deleteAppCouponTypeThirdPartyByIds(ids));
    }

    /**
     * 修改APP第三方管理状态
     */
    @PreAuthorize("@ss.hasPermi('coupon:thirdParty:edit')")
    @Log(title = "APP第三方管理", businessType = BusinessType.UPDATE)
    @PostMapping(value = "updateStatus")
    @ApiOperation(value = "修改APP第三方管理状态")
    public AjaxResult updateAppCouponTypeThirdPartyStatus(@RequestBody AppCouponTypeThirdParty appCouponTypeThirdParty) {
        return toAjax(appCouponTypeThirdPartyService.updateAppCouponTypeThirdPartyStatus(appCouponTypeThirdParty));
    }
}
